#include <robot_dart/robot_dart_simu.hpp>

#ifdef GRAPHIC
#include <robot_dart/gui/magnum/graphics.hpp>
#endif

/// namespace alias for ease of use
namespace rd = robot_dart;

int main()
{
    /// Create simulator object
    rd::RobotDARTSimu simu(0.001);

    /// Load robot
    auto robot = std::make_shared<rd::Robot>("arm.urdf");

    /// Add robot to the world
    simu.add_robot(robot);

    /// Create graphics
#ifdef GRAPHIC
    auto graphics = std::make_shared<rd::gui::magnum::Graphics>();
    simu.set_graphics(graphics);
#endif

    /// Fix robot to world frame
    robot->fix_to_world();

    /// Put the robot in some joint positions
    robot->set_positions(rd::make_vector({1., -0.8, 1.5, 0.2}));

    /// Change the actuator type
    robot->set_actuator_types("servo"); // available actuator types: torque, servo, velocity, locked, mimic

    /// Run simulation
    while (true) {
        if (simu.step_world())
            break;
    }

    return 0;
}
