#include <robot_dart/robot_dart_simu.hpp>

#ifdef GRAPHIC
#include <robot_dart/gui/magnum/graphics.hpp>
#endif

/// namespace alias for ease of use
namespace rd = robot_dart;

int main()
{
    /// Create simulator object
    rd::RobotDARTSimu simu(0.001);

    /// Create graphics
#ifdef GRAPHIC
    auto graphics = std::make_shared<rd::gui::magnum::Graphics>();
    simu.set_graphics(graphics);
    graphics->look_at({0., 2.5, 0.5}, {0., 0., 0.}); // position_of_the_camera, point_to_look_at
#endif

    /// Create robot
    auto robot = std::make_shared<rd::Robot>("pendulum.urdf");
    robot->fix_to_world();
    robot->set_actuator_types("torque");
    auto dofs = robot->dof_names();
    std::cout << "The robot has " << dofs.size() << " DoF(s):" << std::endl;
    for (auto& s : dofs)
        std::cout << "    " << s << std::endl;

    std::cout << "and " << robot->body_names().size() << " links:" << std::endl;
    for (auto& b : robot->body_names())
        std::cout << "    " << b << std::endl;

    robot->set_draw_axis(robot->body_name(0), 0.5);
    robot->set_draw_axis(robot->body_name(1), 0.25);
    simu.add_robot(robot);

    /// Give a small push to the robot
    robot->set_external_torque(robot->body_name(1), {0., 0.01, 0.});

    /// Run simulation
    while (true) {
        if (simu.step_world())
            break;
        // the external forces/torques are not reset and always applied, if we do not set them to zero
        // std::cout << robot->external_forces(robot->body_name(1)).transpose() << std::endl;
    }

    return 0;
}
