import numpy as np
import RobotDART as rd
import dartpy # OSX breaks if this is imported before RobotDART

########## Create simulator object ##########
time_step = 0.001
simu = rd.RobotDARTSimu(time_step)

########## Create Graphics ##########
graphics = rd.gui.Graphics()
simu.set_graphics(graphics)
graphics.look_at([-2., 3., 2.], [0., 0., 0.]) # position_of_the_camera, point_to_look_at

########## Create world frame ##########
# size_of_box[x,y,z], pose, "fixed"/"free", color, name
box0 = rd.Robot.create_box(np.ones((3,1))*0.00001, np.zeros((6,1)), "fixed", color=[0., 0., 0., 1.], box_name="world_frame")
box0.set_ghost() # do not simulate dynamics/collisions for this: visual only
box0.set_cast_shadows(False) # do not cast shadows
box0.set_draw_axis(box0.body_name(0), 1.)
simu.add_robot(box0)

########## Create letter T ##########
box1_size = [0.1, 0.1, 0.5]
tf1 = dartpy.math.Isometry3()
tf1.set_rotation(dartpy.math.eulerZYXToMatrix([np.pi / 3., 0., 0.])) # rotate around Z-axis
tf1.set_translation([0., 0.5, box1_size[2] / 2.]) # translate
box1 = rd.Robot.create_box(box1_size, tf1, "fixed", color=[0.9, 0.1, 0.1, 1.0], box_name="box_1")
box1.set_draw_axis(box1.body_name(0), 0.5)
simu.add_robot(box1)

box2_size = [0.1, 0.5, 0.1]
tf2 = dartpy.math.Isometry3()
tf2.set_rotation(dartpy.math.eulerZYXToMatrix([np.pi / 3., 0., 0.]))
tf2.set_translation([0., 0.5, box1_size[2] + box2_size[2] / 2.])
box2 = rd.Robot.create_box(box2_size, tf2, "fixed", color=[0.9, 0.1, 0.1, 1.0], box_name="box_2")
box2.set_draw_axis(box2.body_name(0), 0.5)
simu.add_robot(box2)

########## Create letter Π ##########
box3_size = [0.1, 0.1, 0.5]
tf3 = dartpy.math.Isometry3()
# tf3.set_rotation(dartpy.math.eulerZYXToMatrix([0., 0., 0.]))
tf3.set_translation([-0.9, 0., box3_size[2] / 2.])
box3 = rd.Robot.create_box(box3_size, tf3, "fixed", color=[0.1, 0.2, 0.9, 1.0], box_name="box_3")
box3.set_draw_axis(box3.body_name(0), 0.5)
simu.add_robot(box3)

box4 = box3.clone()
tf4 = dartpy.math.Isometry3()
# tf4.set_rotation(dartpy.math.eulerZYXToMatrix([0., 0., 0.]))
tf4.set_translation([-1.3, 0., box3_size[2] / 2.])
box4.set_base_pose(tf4)
box4.set_draw_axis(box4.body_name(0), 0.5)
simu.add_robot(box4)

box5_size = [0.1, 0.7, 0.1]
tf5 = dartpy.math.Isometry3()
tf5.set_rotation(dartpy.math.eulerZYXToMatrix([np.pi / 2., 0., 0.]))
tf5.set_translation([-1.1, 0., box3_size[2] + box5_size[2] / 2.])
box5 = rd.Robot.create_box(box5_size, tf5, "fixed", color=[0.1, 0.2, 0.9, 1.0], box_name="box_5")
box5.set_draw_axis(box5.body_name(0), 0.5)
simu.add_robot(box5)

########## Add floor ##########
simu.add_checkerboard_floor()

########## Run simulation ##########
while True:
    if simu.step():
        break
