import numpy as np
import RobotDART as rd
import dartpy # OSX breaks if this is imported before RobotDART

########## Create simulator object ##########
time_step = 0.001
simu = rd.RobotDARTSimu(time_step)

########## Create Graphics ##########
gconfig = rd.gui.GraphicsConfiguration(1024, 768) # Create a window of 1024x768 resolution/size
graphics = rd.gui.Graphics(gconfig) # create graphics object with configuration
simu.set_graphics(graphics)
graphics.look_at([0., -4., 2.0], [0., 0., 0.])
# Record video to "demo.mp4" file
graphics.camera().record(True)
graphics.record_video("demo.mp4")

########## Create Seesaw ##########
box1_size = [0.1, 0.1, 0.2]
tf = dartpy.math.Isometry3()
tf.set_translation([0., 0.0, box1_size[2] / 2.])
box1 = rd.Robot.create_box(box1_size, tf, "fixed", color=[0.9, 0.1, 0.1, 1.], box_name="box_1")
simu.add_robot(box1)

box2_size = [0.1, 1., 0.05]
tf = dartpy.math.Isometry3()
tf.set_rotation(dartpy.math.eulerZYXToMatrix([np.pi / 2., 0., 0.]))
tf.set_translation([0., 0., box1_size[2] + box2_size[2] / 2.])
box2 = rd.Robot.create_box(box2_size, tf, "free", color=[0.1, 0.9, 0.1, 1.], box_name="box_2")
simu.add_robot(box2)

########## Create a ball ##########
sphere_size = [0.3]*3
tf = dartpy.math.Isometry3()
tf.set_translation([0.4, 0., 5.])
sphere = rd.Robot.create_ellipsoid(sphere_size, tf, "free", mass=2., color=[0.1, 0.2, 0.9, 1.], ellipsoid_name="sphere")
simu.add_robot(sphere)

########## Load a robot ##########
robot = rd.Robot("pexod.urdf")
robot.set_position_enforced(True)
robot.set_actuator_types("servo") # un-comment this one to have a "dead" hexapod
tf = dartpy.math.Isometry3()
tf.set_translation([-0.3, 0.0, 0.4])
robot.set_base_pose(tf)
robot.set_draw_axis(robot.body_name(0), 0.5)
simu.add_robot(robot)

########## Add floor ##########
simu.add_checkerboard_floor()

########## Run simulation ##########
while True:
    if simu.step():
        break
