import numpy as np
import RobotDART as rd
import dartpy # OSX breaks if this is imported before RobotDART

########## Create simulator object ##########
time_step = 0.001
simu = rd.RobotDARTSimu(time_step)

########## Create Graphics ##########
graphics = rd.gui.Graphics()
simu.set_graphics(graphics)
graphics.look_at([0., 2.5, 0.5], [0., 0., 0.])

########## Create robot ##########
robot = rd.Robot("pendulum.urdf")
robot.fix_to_world()
robot.set_actuator_types("torque")
dofs = robot.dof_names()
print("The robot has " + str(len(dofs)) + " DoF(s):")
print(dofs)
print("and " + str(len(robot.body_names())) + " links:")
print(robot.body_names())
robot.set_draw_axis(robot.body_name(0), 0.5)
robot.set_draw_axis(robot.body_name(1), 0.25)
simu.add_robot(robot)

########## Give a small push to the robot ##########
robot.set_external_torque(robot.body_name(1), [0., 0.01, 0.])

########## Run simulation ##########
while True:
    if simu.step_world():
        break
    # the external forces/torques are not reset and always applied, if we do not set them to zero
    # print(robot.external_forces(robot.body_name(1)))
